import { HttpClient, NonNullablePaths, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { AsyncJob, ListAsyncJobItemsOptions, ListAsyncJobItemsResponse } from './index.typings.js';
export { ActionEvent, AnonymousVisitorIdOptions, AppIdOptions, ApplicationError, AsyncJobFailedEvent, AsyncJobFinishedEvent, AsyncJobItem, AsyncJobItemAddedEvent, AsyncJobItemFailedEvent, CompleteAsyncJobRequest, CompleteAsyncJobResponse, CompleteStatus, Counters, Counts, CreateAsyncJobRequest, CreateAsyncJobResponse, CreatedBy, CreatedByOptionsOneOf, CursorPaging, Cursors, DeleteAsyncJobRequest, DeleteAsyncJobResponse, DomainEvent, DomainEventBodyOneOf, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, GetAsyncJobRequest, GetAsyncJobResponse, IdentificationData, IdentificationDataIdOneOf, ListAsyncJobItemsRequest, MemberIdOptions, MessageEnvelope, Owner, OwnerIdOneOf, PagingMetadataV2, ReportAsyncJobProgressRequest, ReportAsyncJobProgressResponse, RestoreInfo, Status, StatusFilter, Type, UpdateAsyncJobRequest, UpdateAsyncJobResponse, WebhookIdentityType, WixUserIdOptions } from './index.typings.js';

type AsyncJobNonNullablePaths = `_id` | `status` | `counters.itemsSucceeded` | `counters.itemsFailed` | `owner.anonymousVisitorId` | `owner.memberId` | `owner.wixUserId` | `owner.appId` | `owner.serviceId` | `createdBy.anonymousVisitorIdOptions.anonymousVisitorId` | `createdBy.memberIdOptions.memberId` | `createdBy.wixUserIdOptions.wixUserId` | `createdBy.appIdOptions.appId` | `createdBy.type` | `counts.successCount` | `counts.failCount`;
declare function getAsyncJob$1(httpClient: HttpClient): GetAsyncJobSignature;
interface GetAsyncJobSignature {
    /**
     * Retrieves a job.
     * @param - Job ID.
     * @returns Returned job.
     */
    (jobId: string): Promise<NonNullablePaths<AsyncJob, AsyncJobNonNullablePaths>>;
}
declare function listAsyncJobItems$1(httpClient: HttpClient): ListAsyncJobItemsSignature;
interface ListAsyncJobItemsSignature {
    /**
     * Retrieves a list of job items.
     * @param - Job ID.
     * @param - Field options.
     */
    (jobId: string, options?: ListAsyncJobItemsOptions): Promise<NonNullablePaths<ListAsyncJobItemsResponse, `results` | `results.${number}._id` | `results.${number}.success` | `results.${number}.error.code` | `results.${number}.error.description`>>;
}

declare const getAsyncJob: MaybeContext<BuildRESTFunction<typeof getAsyncJob$1> & typeof getAsyncJob$1>;
declare const listAsyncJobItems: MaybeContext<BuildRESTFunction<typeof listAsyncJobItems$1> & typeof listAsyncJobItems$1>;

export { AsyncJob, ListAsyncJobItemsOptions, ListAsyncJobItemsResponse, getAsyncJob, listAsyncJobItems };
