// src/infra-asyncjobs-v1-async-job-async-jobs.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/infra-asyncjobs-v1-async-job-async-jobs.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveWixInfraAsyncjobsV1AsyncJobServiceUrl(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/async-job-service",
        destPath: ""
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/async-jobs",
        destPath: "/v1/async-jobs"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/async-jobs",
        destPath: ""
      }
    ],
    _: [
      {
        srcPath: "/_api/async-jobs",
        destPath: ""
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/async-jobs",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_async-jobs_async-jobs";
function getAsyncJob(payload) {
  function __getAsyncJob({ host }) {
    const metadata = {
      entityFqdn: "wix.infra.asyncjobs.v1.async_job",
      method: "GET",
      methodFqn: "wix.infra.asyncjobs.v1.AsyncJobService.GetAsyncJob",
      packageName: PACKAGE_NAME,
      url: resolveWixInfraAsyncjobsV1AsyncJobServiceUrl({
        protoPath: "/v1/async-jobs/{jobId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [{ path: "job.createdDate" }, { path: "job.updatedDate" }]
        }
      ])
    };
    return metadata;
  }
  return __getAsyncJob;
}
function listAsyncJobItems(payload) {
  function __listAsyncJobItems({ host }) {
    const metadata = {
      entityFqdn: "wix.infra.asyncjobs.v1.async_job",
      method: "GET",
      methodFqn: "wix.infra.asyncjobs.v1.AsyncJobService.ListAsyncJobItems",
      packageName: PACKAGE_NAME,
      url: resolveWixInfraAsyncjobsV1AsyncJobServiceUrl({
        protoPath: "/v1/async-jobs/{jobId}/items",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __listAsyncJobItems;
}

// src/infra-asyncjobs-v1-async-job-async-jobs.universal.ts
var Type = /* @__PURE__ */ ((Type2) => {
  Type2["UNKNOWN_TYPE"] = "UNKNOWN_TYPE";
  Type2["ANONYMOUS_VISITOR_ID"] = "ANONYMOUS_VISITOR_ID";
  Type2["MEMBER_ID"] = "MEMBER_ID";
  Type2["WIX_USER_ID"] = "WIX_USER_ID";
  Type2["APP_ID"] = "APP_ID";
  return Type2;
})(Type || {});
var Status = /* @__PURE__ */ ((Status2) => {
  Status2["UNKNOWN"] = "UNKNOWN";
  Status2["INITIALIZED"] = "INITIALIZED";
  Status2["PROCESSING"] = "PROCESSING";
  Status2["FINISHED"] = "FINISHED";
  Status2["FAILED"] = "FAILED";
  return Status2;
})(Status || {});
var CompleteStatus = /* @__PURE__ */ ((CompleteStatus2) => {
  CompleteStatus2["FINISHED"] = "FINISHED";
  CompleteStatus2["FAILED"] = "FAILED";
  return CompleteStatus2;
})(CompleteStatus || {});
var StatusFilter = /* @__PURE__ */ ((StatusFilter2) => {
  StatusFilter2["ALL"] = "ALL";
  StatusFilter2["FAILED_ONLY"] = "FAILED_ONLY";
  StatusFilter2["SUCCESSFUL_ONLY"] = "SUCCESSFUL_ONLY";
  return StatusFilter2;
})(StatusFilter || {});
var WebhookIdentityType = /* @__PURE__ */ ((WebhookIdentityType2) => {
  WebhookIdentityType2["UNKNOWN"] = "UNKNOWN";
  WebhookIdentityType2["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
  WebhookIdentityType2["MEMBER"] = "MEMBER";
  WebhookIdentityType2["WIX_USER"] = "WIX_USER";
  WebhookIdentityType2["APP"] = "APP";
  return WebhookIdentityType2;
})(WebhookIdentityType || {});
async function getAsyncJob2(jobId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({ jobId });
  const reqOpts = getAsyncJob(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data)?.job;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { jobId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["jobId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function listAsyncJobItems2(jobId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    jobId,
    paging: options?.paging,
    statusFilter: options?.statusFilter
  });
  const reqOpts = listAsyncJobItems(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          jobId: "$[0]",
          paging: "$[1].paging",
          statusFilter: "$[1].statusFilter"
        },
        singleArgumentUnchanged: false
      },
      ["jobId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
export {
  CompleteStatus,
  Status,
  StatusFilter,
  Type,
  WebhookIdentityType,
  getAsyncJob2 as getAsyncJob,
  listAsyncJobItems2 as listAsyncJobItems
};
//# sourceMappingURL=index.typings.mjs.map