import { GetAsyncJobRequest as GetAsyncJobRequest$1, GetAsyncJobResponse as GetAsyncJobResponse$1, ListAsyncJobItemsRequest as ListAsyncJobItemsRequest$1, ListAsyncJobItemsResponse as ListAsyncJobItemsResponse$1 } from './index.typings.mjs';
import '@wix/sdk-types';

interface AsyncJob {
    /**
     * Job ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /** Optional job metadata, used to store any parameters used during job execution, user-defined statuses, etc. */
    metadata?: Record<string, any> | null;
    /** Current job execution status. */
    status?: StatusWithLiterals;
    /**
     * Current counters.
     * @deprecated Current counters.
     * @replacedBy wix.infra.asyncjobs.v1.AsyncJob.counts
     * @targetRemovalDate 2024-12-12
     */
    counters?: Counters;
    /**
     * Date and time the job was created in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601#combined_date_and_time_representations) format.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the job was last updated in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601#combined_date_and_time_representations) format.
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * Job owner.
     * @readonly
     * @deprecated Job owner.
     * @replacedBy wix.infra.asyncjobs.v1.AsyncJob.created_by
     * @targetRemovalDate 2024-12-12
     */
    owner?: Owner;
    /**
     * Job creator.
     * @readonly
     */
    createdBy?: CreatedBy;
    /** Current execution counts. */
    counts?: Counts;
}
declare enum Type {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    /** Job was created by a site visitor that was **not** logged in. */
    ANONYMOUS_VISITOR_ID = "ANONYMOUS_VISITOR_ID",
    /** Job was created by a **logged in** site visitor. */
    MEMBER_ID = "MEMBER_ID",
    /** Job was created by a  Wix user. */
    WIX_USER_ID = "WIX_USER_ID",
    /** Job was created by an external app or app by Wix. */
    APP_ID = "APP_ID"
}
/** @enumType */
type TypeWithLiterals = Type | 'UNKNOWN_TYPE' | 'ANONYMOUS_VISITOR_ID' | 'MEMBER_ID' | 'WIX_USER_ID' | 'APP_ID';
interface AnonymousVisitorIdOptions {
    /**
     * Visitor ID - When the job is owned by a site visitor that was **not** logged in.
     * @format GUID
     */
    anonymousVisitorId?: string;
}
interface MemberIdOptions {
    /**
     * Member ID - When the job is owned by a by a **logged in** site visitor.
     * @format GUID
     */
    memberId?: string;
}
interface WixUserIdOptions {
    /**
     * User ID - When the job is owned by a site owner or contributor.
     * @format GUID
     */
    wixUserId?: string;
}
interface AppIdOptions {
    /**
     * App ID - When the job is owned by an external app. or app by Wix.
     * @format GUID
     */
    appId?: string;
}
declare enum Status {
    UNKNOWN = "UNKNOWN",
    /** Job is created, but hasn't started yet. */
    INITIALIZED = "INITIALIZED",
    /** Job has started and is in progress. */
    PROCESSING = "PROCESSING",
    /** Job is finished. */
    FINISHED = "FINISHED",
    /** Job has failed. */
    FAILED = "FAILED"
}
/** @enumType */
type StatusWithLiterals = Status | 'UNKNOWN' | 'INITIALIZED' | 'PROCESSING' | 'FINISHED' | 'FAILED';
interface Counters {
    /** Optional count of the dataset size, as specified during job creation. Can be used for progress bars, etc. */
    itemsToProcess?: number | null;
    /** Amount of items that were successfully processed. */
    itemsSucceeded?: number;
    /** Amount of items whose processing failed. */
    itemsFailed?: number;
    /** Mapping between an error code and the number of failures associated with it. */
    errorCountByCode?: Record<string, number>;
}
interface Owner extends OwnerIdOneOf {
    /**
     * Visitor ID - when the job is owned by a site visitor that was **not** logged in.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Member ID - When the job is owned by a by a **logged in** site visitor.
     * @format GUID
     */
    memberId?: string;
    /**
     * User ID - When the job is owned by a Wix user.
     * @format GUID
     */
    wixUserId?: string;
    /**
     * App ID - When the job is owned by an external app or app by Wix.
     * @format GUID
     */
    appId?: string;
    /**
     * Service ID.
     * @format GUID
     */
    serviceId?: string;
}
/** @oneof */
interface OwnerIdOneOf {
    /**
     * Visitor ID - when the job is owned by a site visitor that was **not** logged in.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Member ID - When the job is owned by a by a **logged in** site visitor.
     * @format GUID
     */
    memberId?: string;
    /**
     * User ID - When the job is owned by a Wix user.
     * @format GUID
     */
    wixUserId?: string;
    /**
     * App ID - When the job is owned by an external app or app by Wix.
     * @format GUID
     */
    appId?: string;
    /**
     * Service ID.
     * @format GUID
     */
    serviceId?: string;
}
interface CreatedBy extends CreatedByOptionsOneOf {
    /** Visitor ID - when the job is created by a site visitor that was **not** logged in. */
    anonymousVisitorIdOptions?: AnonymousVisitorIdOptions;
    /** Member ID - When the job is created by a by a **logged in** site visitor. */
    memberIdOptions?: MemberIdOptions;
    /** User ID - When the job is created by a Wix user. */
    wixUserIdOptions?: WixUserIdOptions;
    /** App ID - When the job is created by an external app or app by Wix. */
    appIdOptions?: AppIdOptions;
    /** The type of the creator. */
    type?: TypeWithLiterals;
}
/** @oneof */
interface CreatedByOptionsOneOf {
    /** Visitor ID - when the job is created by a site visitor that was **not** logged in. */
    anonymousVisitorIdOptions?: AnonymousVisitorIdOptions;
    /** Member ID - When the job is created by a by a **logged in** site visitor. */
    memberIdOptions?: MemberIdOptions;
    /** User ID - When the job is created by a Wix user. */
    wixUserIdOptions?: WixUserIdOptions;
    /** App ID - When the job is created by an external app or app by Wix. */
    appIdOptions?: AppIdOptions;
}
interface Counts {
    /** Optional count of the dataset size, specified during job creation. Can be used for progress bars, etc. */
    total?: number | null;
    /** Amount of items that were successfully processed. */
    successCount?: number;
    /** Amount of items whose processing failed. */
    failCount?: number;
    /** Mapping between an error code and the number of failures associated with it. */
    errorByCodeCount?: Record<string, number>;
}
interface AsyncJobItem {
    /**
     * Job item ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /** Job item data, as passed by the originating service. */
    data?: Record<string, any> | null;
    /**
     * ID of the entity being processed, as passed by the originating service.
     * @minLength 1
     * @maxLength 32
     * @immutable
     */
    entityId?: string | null;
    /**
     * Whether the job item was processed successfully.
     * @readonly
     */
    success?: boolean;
    /**
     * Error that prevented the item from being processed, if relevant.
     * @immutable
     */
    error?: ApplicationError;
}
interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
interface GetAsyncJobRequest {
    /**
     * Job ID.
     * @format GUID
     */
    jobId: string;
}
interface GetAsyncJobResponse {
    /** Returned job. */
    job?: AsyncJob;
}
interface ListAsyncJobItemsRequest {
    /**
     * Job ID.
     * @format GUID
     */
    jobId: string;
    /** Pagination options. */
    paging?: CursorPaging;
    /** async job item status filter. */
    statusFilter?: StatusFilterWithLiterals;
}
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
declare enum StatusFilter {
    /** Return all items. */
    ALL = "ALL",
    /** Return only failed items. */
    FAILED_ONLY = "FAILED_ONLY",
    /** Return only successful items. */
    SUCCESSFUL_ONLY = "SUCCESSFUL_ONLY"
}
/** @enumType */
type StatusFilterWithLiterals = StatusFilter | 'ALL' | 'FAILED_ONLY' | 'SUCCESSFUL_ONLY';
interface ListAsyncJobItemsResponse {
    /** Job items. */
    results?: AsyncJobItem[];
    /** Paging metadata. */
    pagingMetadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor pointing to next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function getAsyncJob(): __PublicMethodMetaInfo<'GET', {
    jobId: string;
}, GetAsyncJobRequest$1, GetAsyncJobRequest, GetAsyncJobResponse$1, GetAsyncJobResponse>;
declare function listAsyncJobItems(): __PublicMethodMetaInfo<'GET', {
    jobId: string;
}, ListAsyncJobItemsRequest$1, ListAsyncJobItemsRequest, ListAsyncJobItemsResponse$1, ListAsyncJobItemsResponse>;

export { type __PublicMethodMetaInfo, getAsyncJob, listAsyncJobItems };
